@@ -2,7 +2,7 @@ package App::gh;
 use warnings;
 use strict;
 
-our $VERSION = '0.252';
+our $VERSION = '0.253';
 
 __END__
 
@@ -15,7 +15,8 @@ App::gh - An apt-like Github utility.
 App-gh provides an interface for you clone, fork, search github repository very
 easily. You can even clone all repositories from an author , for example:
 
-    $ gh cloneall miyagawa
+    $ gh all miyagawa
+    $ gh all miyagawa --into path/
 
 this will clone all repositories of miyagawa.
 
@@ -40,6 +41,12 @@ And you might want to show all forks of this repository:
 
     $ gh network
 
+to pull changes from one fork.
+
+    $ gh pull gugod [branch]
+
+This will pull changes from gugod/[branch].  specify --merge to merge these
+changes. --branch if you want the forked branch to be checked out.
 
 =head1 SYNOPSIS
 
@@ -47,10 +54,6 @@ list all repository of c9s:
 
     $ gh list c9s
 
-if you want text wrapped:
-
-    $ WRAP=1 gh list c9s
-
 clone Plack repository from miyagawa:
 
     $ gh clone miyagawa/Plack   # default: read-only 
@@ -59,17 +62,17 @@ or:
 
     $ gh clone miyagawa Plack
 
-    $ gh clone gugod Social http
+    $ gh clone gugod Social --http
 
-    $ gh clone clkao Web-Hippie ro
+    $ gh clone clkao Web-Hippie --ro
 
 clone from read-only uri:
 
-    $ gh clone miyagawa/Plack ro 
+    $ gh clone miyagawa/Plack --ro 
 
 clone from ssh uri:
 
-    $ gh clone miyagawa/Plack ssh  
+    $ gh clone miyagawa/Plack --ssh  
 
 search repository:
 
@@ -77,13 +80,14 @@ search repository:
 
 to clone all repository of miyagawa:
 
-    $ gh cloneall miyagawa 
-
-    $ gh cloneall clkao ro  # read-only
+    $ gh all miyagawa 
+    $ gh all clkao --ro  # read-only
+    $ gh all clkao --into path/to/clkao
 
 to fork project:
 
-    $ gh fork clkao AnyMQ
+    $ cd AnyMQ
+    $ gh fork clkao
 
 to fork current project:
 
