@@ -26,15 +26,41 @@ For example:
 
 This will create a gugod-master branch:
 
+=head1 OPTIONS
+
+    --branch 
+    
+    create tracked branch for fork.
+
+    --merge
+
+    merge changes from fork.
+
+=head3 Github Steps:
+
+Step 1: Check out a new branch to test the changes — run this from your project directory
+
+    git checkout -b chocolateboy-optional_dep_and_warnings_fixes master
+
+Step 2: Bring in chocolateboy's changes and test
+
+    git pull http://github.com/chocolateboy/App-gh.git optional_dep_and_warnings_fixes
+
+Step 3: Merge the changes and update the server
+
+    git checkout master
+    git merge chocolateboy-optional_dep_and_warnings_fixes
+    git push origin master
+
 =cut
 
 sub options { (
-        "m|merge" => "merge",
-        "verbose" => "verbose",
-
-        "ssh" => "protocal_ssh",    # git@github.com:c9s/repo.git
-        "http" => "protocal_http",  # http://github.com/c9s/repo.git
-        "https" => "https",         # https://github.com/c9s/repo.git
+        "m|merge"  => "merge",
+        "b|branch" => "branch",
+        "verbose"  => "verbose",
+        "ssh"      => "protocal_ssh",    # git@github.com:c9s/repo.git
+        "http"     => "protocal_http",  # http://github.com/c9s/repo.git
+        "https"    => "https",         # https://github.com/c9s/repo.git
         "git|ro"   => "git"         # git://github.com/c9s/repo.git
     ) }
 
@@ -75,25 +101,33 @@ sub run {
 
     die "git config not found." if  ! -e ".git/config" ;
 
+    my $remote_name      = $acc;
     my $fork_branch_name = "$acc-$from_branch";
-    my $current_repo = $self->get_current_repo();
-    my $fork_uri = $self->gen_uri( $acc , $current_repo );
+    my $current_repo     = $self->get_current_repo();
+    my $fork_uri         = $self->gen_uri( $acc , $current_repo );
 
-    unless( qx(git remote | grep $acc ) ) {
-        print "Adding remote [$acc] for [$fork_uri]\n";
-        qx(git remote add $acc $fork_uri);
+    unless( qx(git remote | grep $remote_name ) ) {
+        print "Adding remote [$remote_name] for [$fork_uri]\n";
+        qx(git remote add $remote_name $fork_uri);
     }
 
     print "Fetching $acc ...\n";
-    qx(git fetch $acc);
+    print qx(git fetch $acc);
+
 
     if( $self->{merge} ) {
         print "Checking out $to_branch ...\n";
         qx(git checkout $to_branch);
 
         print "Merging changes from [$acc/$from_branch] to $to_branch\n";
-        qx(git merge $acc/$from_branch);
+        print qx(git merge $acc/$from_branch);
     }
+
+    if( $self->{branch} ) {
+        print "Creating track branch for $acc/$from_branch\n";
+        print qx(git checkout --track -b $fork_branch_name $acc/$from_branch);
+    }
+
     print "Done\n";
 }
 
